MBTickerType enum

Inheritance
Available extensions

Values

last → const MBTickerType
first → const MBTickerType
mean → const MBTickerType
std → const MBTickerType
min → const MBTickerType
max → const MBTickerType
sum → const MBTickerType

Properties

description → String

Available on MBTickerType, provided by the MBTickerTypeExtension extension

no setter
displayName → String

Available on MBTickerType, provided by the MBTickerTypeExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData

Available on MBTickerType, provided by the MBTickerTypeExtension extension

no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortenedDisplayName → String

Available on MBTickerType, provided by the MBTickerTypeExtension extension

no setter
value → MBInfo

Available on MBTickerType, provided by the MBTickerTypeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<MBTickerType>
A constant List of the values in this enum, in order of their declaration.