GraphWidget class abstract
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GraphWidget
- Implementers
- BubbleGraph
- CandleStickGraph
- ChecklistProgressGauge
- ColumnGraph
- ECGGraph
- FastLineGraph
- FullRadialGraph
- HistogramGraph
- LabelGraph
- LabelModeGraph
- LinearGaugeGraph
- LineGraph
- NumberGraph
- NumberSplitGraph
- RadialGraph
- RadialHorizontalGraph
- RadialIconGraph
- ScatterGraph
- StackedBarGraph
- StackedColumnGraph
- StepLineGraph
Constructors
-
GraphWidget({Key? key, required MBGraphSize graphSize, required MBTickerType tickerType, required MBTimeWindow timeWindow, required Map<
String, dynamic> variable, required Color color, required double height, required List<MBGraphSize> allowedSizes, required List<MBVariableType> allowedVariableTypes, required List<MBVariableForm> allowedVariableForms, required DateTime referenceTime}) -
const
Properties
-
allowedSizes
→ List<
MBGraphSize> -
Defines constraints for each graph type
final
-
allowedVariableForms
→ List<
MBVariableForm> -
final
-
allowedVariableTypes
→ List<
MBVariableType> -
final
- color → Color
-
final
- graphSize → MBGraphSize
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- referenceTime → DateTime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickerType → MBTickerType
-
final
- timeWindow → MBTimeWindow
-
final
-
variable
→ Map<
String, dynamic> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildGraph(
BuildContext context) → Widget -
buildSeries(
BuildContext context, List< ChartData> chartData) → CartesianSeries<ChartData, DateTime> -
buildSize(
BuildContext context) → Widget -
buildSplit(
BuildContext context) → Widget -
buildTicker(
BuildContext context) → Widget -
buildWidget(
BuildContext context) → Widget -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited