LabelModeGraph class

Inheritance

Constructors

LabelModeGraph({Key? key, required Map<String, dynamic> variable, required Color color, required MBTimeWindow timeWindow, required MBTickerType tickerType, required MBGraphSize graphSize, required double height, required DateTime referenceTime})
const

Properties

allowedSizes → List<MBGraphSize>
Defines constraints for each graph type
finalinherited
allowedVariableForms → List<MBVariableForm>
finalinherited
allowedVariableTypes → List<MBVariableType>
finalinherited
color → Color
finalinherited
graphSize → MBGraphSize
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
referenceTime → DateTime
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tickerType → MBTickerType
finalinherited
timeWindow → MBTimeWindow
finalinherited
variable → Map<String, dynamic>
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildGraph(BuildContext context) → Widget
inherited
buildSeries(BuildContext context, List<ChartData> chartData) → CartesianSeries<ChartData, DateTime>
inherited
buildSize(BuildContext context) → Widget
inherited
buildSplit(BuildContext context) → Widget
inherited
buildTicker(BuildContext context) → Widget
inherited
buildWidget(BuildContext context) → Widget
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited