MBInfo class

Constructors

MBInfo({required String display, required String description, required String code, Color? color, String? icon})

Properties

code String
final
color Color?
final
description String
final
display String
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited