MBProfile class

Constructors

MBProfile({required String display, required String description, required String photoUrl, required String uid})

Properties

description → String
final
display → String
final
hashCode → int
The hash code for this object.
no setterinherited
photoUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited