MBVariablePreset class

Constructors

MBVariablePreset({required String display, required String description, required String code, required Color color, required String icon, MBRange? range, required String type, required String unit})

Properties

code String
final
color Color
final
description String
final
display String
final
hashCode int
The hash code for this object.
no setterinherited
icon String
final
range MBRange?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
unit String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited