RegulatoryTask class

Constructors

RegulatoryTask({required String id, required String title, required String description, List<String> resources = const [], List<String> dependsOn = const [], bool isCompleted = false})

Properties

dependsOn List<String>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isCompleted bool
getter/setter pair
resources List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

canAccess(List<RegulatoryTask> allTasks) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited