MBTimeWindow enum

Inheritance
Available extensions

Values

lastMinute → const MBTimeWindow
last15Minutes → const MBTimeWindow
lastHour → const MBTimeWindow
last24Hours → const MBTimeWindow
last7Days → const MBTimeWindow
last30Days → const MBTimeWindow
pastYear → const MBTimeWindow
auto → const MBTimeWindow
none → const MBTimeWindow

Properties

displayName String

Available on MBTimeWindow, provided by the MBTimeWindowExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MBTimeWindow>
A constant List of the values in this enum, in order of their declaration.