TimelineData class
Constructors
-
TimelineData({required DeviceClass deviceClass, required int currentStep, required Map<
String, bool> checklistStatus}) -
TimelineData.fromJson(Map<
String, dynamic> json) -
Creates a TimelineData instance from JSON data
factory
- TimelineData.fromJsonString(String jsonString)
-
Creates a TimelineData instance from a JSON string
factory
Properties
-
checklistStatus
→ Map<
String, bool> -
final
- currentStep → int
-
final
- deviceClass → DeviceClass
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited